# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: boundlessgeo_schema/Metadata.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='boundlessgeo_schema/Metadata.proto',
  package='',
  syntax='proto3',
  serialized_pb=_b('\n\"boundlessgeo_schema/Metadata.proto\"o\n\x08Metadata\x12/\n\x0btracingTags\x18\x01 \x03(\x0b\x32\x1a.Metadata.TracingTagsEntry\x1a\x32\n\x10TracingTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42.\n\x17\x63om.boundlessgeo.schemaB\x0bMetadataPbfZ\x06schemab\x06proto3')
)
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_METADATA_TRACINGTAGSENTRY = _descriptor.Descriptor(
  name='TracingTagsEntry',
  full_name='Metadata.TracingTagsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Metadata.TracingTagsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='Metadata.TracingTagsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001')),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=99,
  serialized_end=149,
)

_METADATA = _descriptor.Descriptor(
  name='Metadata',
  full_name='Metadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tracingTags', full_name='Metadata.tracingTags', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_METADATA_TRACINGTAGSENTRY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=38,
  serialized_end=149,
)

_METADATA_TRACINGTAGSENTRY.containing_type = _METADATA
_METADATA.fields_by_name['tracingTags'].message_type = _METADATA_TRACINGTAGSENTRY
DESCRIPTOR.message_types_by_name['Metadata'] = _METADATA

Metadata = _reflection.GeneratedProtocolMessageType('Metadata', (_message.Message,), dict(

  TracingTagsEntry = _reflection.GeneratedProtocolMessageType('TracingTagsEntry', (_message.Message,), dict(
    DESCRIPTOR = _METADATA_TRACINGTAGSENTRY,
    __module__ = 'boundlessgeo_schema.Metadata_pb2'
    # @@protoc_insertion_point(class_scope:Metadata.TracingTagsEntry)
    ))
  ,
  DESCRIPTOR = _METADATA,
  __module__ = 'boundlessgeo_schema.Metadata_pb2'
  # @@protoc_insertion_point(class_scope:Metadata)
  ))
_sym_db.RegisterMessage(Metadata)
_sym_db.RegisterMessage(Metadata.TracingTagsEntry)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\027com.boundlessgeo.schemaB\013MetadataPbfZ\006schema'))
_METADATA_TRACINGTAGSENTRY.has_options = True
_METADATA_TRACINGTAGSENTRY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001'))
# @@protoc_insertion_point(module_scope)
